@@ -1006,7 +1006,7 @@ initcups (void)
     "Use it like this::\n"
     "  try:\n"
     "    ...\n"
-    "  except cups.HTTPError (status):\n"
+    "  except cups.HTTPError as (status):\n"
     "    print 'HTTP status is %d' % status\n"));
   HTTPError = PyErr_NewException ("cups.HTTPError", NULL, obj);
   Py_DECREF (obj);
@@ -1023,7 +1023,7 @@ initcups (void)
     "Use it like this::\n"
     "  try:\n"
     "    ...\n"
-    "  except cups.IPPError (status, description):\n"
+    "  except cups.IPPError as (status, description):\n"
     "    print 'IPP status is %d' % status\n"
     "    print 'Meaning:', description\n"));
   IPPError = PyErr_NewException ("cups.IPPError", NULL, obj);
